@@ -1,10 +1,12 @@
 #' @title Expected Error Rate
+#' @alias prior, priors
 #' @description Calculate expected OOB error rates (priors) for randomForest 
 #'   classification model based on random assignment and class sizes.
 #' 
 #' @param rf an object inheriting from \code{link{randomForest}}.
 #' 
-#' @return a vector of expected error rates (priors) for each class.
+#' @return a matrix of expected error rates (\code{prior}) and 
+#'   p-values from a binomial test (\code{class_p.value}) for each class.
 #' 
 #' @author Eric Archer \email{eric.archer@@noaa.gov}
 #' 
@@ -21,8 +23,18 @@ exptdErrRate <- function(rf) {
     stop("'rf' is not a randomForest or rfPermute object.")
   }
   if(rf$type == "regression") stop("'rf' must be of a classification model")
-  y.freq <- table(rf$y)
-  exp.err <- 1 - y.freq / sum(y.freq)
-  oob.err <- sum(exp.err * y.freq) / sum(y.freq)
-  c(OOB = oob.err, exp.err)
+  
+  # Get priors
+  cm <- .confMat(rf)
+  class.n <- colSums(cm)
+  total.n <- sum(class.n)
+  exp.err <- 1 - class.n / total.n
+  prior <- c(exp.err, OOB = sum(exp.err * class.n) / total.n)
+  
+  # Get p-values
+  correct.n <- c(diag(cm), sum(diag(cm)))
+  total.n <- c(class.n, total.n)
+  prior.p <- 1 - pbinom(correct.n, total.n, 1 - prior)
+  
+  cbind(prior = prior, class_p.value = prior.p)
 }
